@@ -1,8 +1,9 @@
 """Test Matplotlib ConversionInterface"""
 import numpy as np
 import pytest
-from unyt._on_demand_imports import _matplotlib, NotAModule
-from unyt import m, s, K, unyt_array, unyt_quantity
+
+from unyt import K, m, s, unyt_array, unyt_quantity
+from unyt._on_demand_imports import NotAModule, _matplotlib
 from unyt.exceptions import UnitConversionError
 
 try:
@@ -234,3 +235,9 @@ def test_multiple_subplots():
     assert generated_labels == expected_labels
     _matplotlib.pyplot.close()
     matplotlib_support.disable()
+
+
+@check_matplotlib
+def test_empty_plot(ax):
+    ax.set_xlim(*unyt_array([0, 1], "s"))
+    _matplotlib.pyplot.close()
